@@ -19,6 +19,7 @@
 
 // Qt
 #include <QGuiApplication>
+#include <QCoreApplication>
 #include <QtQml/QQmlDebuggingEnabler>
 
 // local
@@ -31,10 +32,12 @@ static QQmlDebuggingEnabler debuggingEnabler(false);
 
 int main(int argc, char** argv)
 {
-    QGuiApplication::setApplicationName("camera.ubports");
+    QGuiApplication app(argc, argv);
+    QCoreApplication::setApplicationName("camera.ubports");
     // Necessary for Qt.labs.settings to work
     // Ref.: https://bugs.launchpad.net/ubuntu-ui-toolkit/+bug/1354321
     QCoreApplication::setOrganizationDomain(QGuiApplication::applicationName());
+    QCoreApplication::setApplicationVersion(projectVersion());
     CameraApplication application(argc, argv);
 
     if (!application.setup()) {
